@@ -235,7 +235,7 @@ def intergration_window_graph():
     intergrated_wave_axis = []
 
 
-    dict["text_window"] = Tk.Toplevel(root)
+    dict["text_window"] = Tk.Toplevel(dict["root"])
     dict["text_window"].wm_title("Saving window")
 
 
@@ -262,7 +262,7 @@ def intergration_window_graph():
         pixel_numbers_1.append(find_point_from_below(x1, x_axis[0]))
         pixel_numbers_1.append(find_point_from_below(x2, x_axis[0]))
 
-        selection_1 = np.sum(spec[:,:,pixel_numbers_1[0]:pixel_numbers_1[1]],2)*np.median(np.diff(o['wavelength'][0,:]))
+        selection_1 = np.sum(spec[:,:,pixel_numbers_1[0]:pixel_numbers_1[1]],2)*np.median(np.diff(dict["o"]['wavelength'][0,:]))
         #get time stop
         below_zero_points = np.ndarray.flatten(np.asarray(np.where(np.mean(selection_1,1)<0)))
         indx_end = below_zero_points[np.argmax(np.diff(below_zero_points))+1]
@@ -361,7 +361,7 @@ def comparing_ratios():
 
     global dict
 
-    x_axis = output['wavelength']
+    x_axis = dict["output"]['wavelength']
 
     spec = dict["o"]['spectra_abs']
     #clicking_point_1 = dict["fig"].ginput(n=2, timeout=0, show_clicks=True)
@@ -388,8 +388,8 @@ def comparing_ratios():
 
     #spec = dict["o"]['spectra_counts']
 
-    selection_1 = np.sum(spec[:,:,pixel_numbers_1[0]:pixel_numbers_1[1]],2)*np.median(np.diff(o['wavelength'][0,:]))
-    selection_2 = np.sum(spec[:,:,pixel_numbers_2[0]:pixel_numbers_2[1]],2)*np.median(np.diff(o['wavelength'][0,:]))
+    selection_1 = np.sum(spec[:,:,pixel_numbers_1[0]:pixel_numbers_1[1]],2)*np.median(np.diff(dict["o"]['wavelength'][0,:]))
+    selection_2 = np.sum(spec[:,:,pixel_numbers_2[0]:pixel_numbers_2[1]],2)*np.median(np.diff(dict["o"]['wavelength'][0,:]))
 
 
 
@@ -548,16 +548,16 @@ def load_new_data():
     cur_dir = os.getcwd()
     os.chdir('/common/projects/diagnostics/MAST/SPEXBDMS/Lightfield_output/Data_Files/')
     #loads the data
-    output = retrieve_data_from_file()
-    o = output
+    dict["output"] = retrieve_data_from_file()
+    o = dict["output"]
     dict["o"] = o
-    dict["wavelength_r"] = output['wavelength']
-    dict["t"] = output['time']
-    (dict["settings"]) = output['settings']
-    if len(output['spectra_abs'])>0:
-        dict["data_spectra"] = output['spectra_abs']
+    dict["wavelength_r"] = dict["output"]['wavelength']
+    dict["t"] = dict["output"]['time']
+    (dict["settings"]) = dict["output"]['settings']
+    if len(dict["output"]['spectra_abs'])>0:
+        dict["data_spectra"] = dict["output"]['spectra_abs']
     else:
-        dict["data_spectra"] = output['spectra_counts']
+        dict["data_spectra"] = dict["output"]['spectra_counts']
     #changes the directory back
     os.chdir(cur_dir)
     dict["data_spectra"] = np.einsum('kli->lki', dict["data_spectra"]) #Converts from Time, Fibre, Pixel to Fibre, Time, Pixel.
@@ -567,7 +567,7 @@ def load_new_data():
     dict["A"] = dict["data_spectra"].tolist()
 
 
-    for widget in subframe.winfo_children():
+    for widget in dict["subframe"].winfo_children():
         widget.destroy()
     dict["ax_time"].remove()
     dict["ax_fibre"].remove()
@@ -601,7 +601,7 @@ def main(slider_fibre, slider_time):
     modifier = dict["desired_sample_rate"] / dict["current_sample_rate"]
     time_modified = int(time_number * modifier)
 
-    data_lst = A[slider_fibre][time_modified]
+    data_lst = dict["A"][slider_fibre][time_modified]
     data_lst = (dict["A"])[slider_fibre][time_modified]
     data_lst = df.create_single_sublist(data_lst)
     dict["total"] = process(data_lst)
@@ -737,17 +737,17 @@ def open_spectra_window():
     dict["spec_listbox"] = Tk.Listbox(top, selectmode="extended", height = 30, width = 27)
     count = 0
     limits = dict["current_x_axis"]
-    while int(known_spectra_lines[count][1]) < limits[0]:
+    while int(dict["known_spectra_lines"][count][1]) < limits[0]:
         count += 1
     dict["minimum_spectra_line"] = count
     count = -1
-    while int(known_spectra_lines[count][1]) > limits[1]:
+    while int(dict["known_spectra_lines"][count][1]) > limits[1]:
         count -= 1
     maximum_spectra_line = count
 
 
     #selects which spectra lines to show
-    sliced_known_spectra_lines = known_spectra_lines[dict["minimum_spectra_line"]:maximum_spectra_line+1]
+    sliced_known_spectra_lines = dict["known_spectra_lines"][dict["minimum_spectra_line"]:maximum_spectra_line+1]
     sliced_known_spectra_lines = reversed(sliced_known_spectra_lines)
     for i in sliced_known_spectra_lines:
         dict["spec_listbox"].insert(count, (str(i[0][0]) + ' ' + str(i[1])))
@@ -799,7 +799,7 @@ def open_max_min():
     # creates a listbox that allows for multiple selection
     dict["horiz_listbox"] = Tk.Listbox(top_max_min, selectmode="multiple")
     count = 0
-    for i in horizontal:
+    for i in dict["horizontal"]:
         dict["horiz_listbox"].insert(count, i[0])
         count += 1
 
@@ -838,7 +838,7 @@ def spectra_proccess():
     global dict
 
     values = [dict["spec_listbox"].get(idx) for idx in dict["spec_listbox"].curselection()]
-    true_or_false = [False] * (len(known_spectra_lines))
+    true_or_false = [False] * (len(dict["known_spectra_lines"]))
     dict["total_spec"] = dict["spec_listbox"].get(0, Tk.END)
     count = dict["minimum_spectra_line"]
 
@@ -874,7 +874,7 @@ def min_max_proccess():
 
 
     values = [dict["horiz_listbox"].get(idx) for idx in dict["horiz_listbox"].curselection()]
-    true_or_false = [False] * (len(horizontal))
+    true_or_false = [False] * (len(dict["horizontal"]))
     dict["total_spec"] = dict["horiz_listbox"].get(0, Tk.END)
     count = 0
 
@@ -995,7 +995,7 @@ def plot_graph():
     dict["are_zoomed"] = False
 
     # esentially does what plt.show() does but in tkninter
-    canvas = FigureCanvasTkAgg(dict["fig"], subframe)
+    canvas = FigureCanvasTkAgg(dict["fig"], dict["subframe"])
     canvas.get_tk_widget().grid(row=1, column=2)
 
     dict["ax"] = dict["fig"].add_subplot(111)
@@ -1021,33 +1021,33 @@ def plot_graph():
     dict["horizontal_index"] = []
     colour_index = ["b", "r"]
     horizontal_count = 0
-    for i in horizontal:
+    for i in dict["horizontal"]:
         # creating a plot vertically upwards for all the spectra in the spectra list
         blank = 0
         dict["horizontal_index"].append(blank)
         # The labeling allows it to be selected
-        dict["horizontal_index"][horizontal_count], = dict["ax"].plot(infinite, [horizontal[horizontal_count][1],
-                                                                 horizontal[horizontal_count][1]],
+        dict["horizontal_index"][horizontal_count], = dict["ax"].plot(infinite, [dict["horizontal"][horizontal_count][1],
+                                                                 dict["horizontal"][horizontal_count][1]],
                                                       color=colour_index[horizontal_count], visible=False,
-                                                      label=horizontal[horizontal_count][1])
+                                                      label=dict["horizontal"][horizontal_count][1])
         horizontal_count += 1
 
     dict["spectra_index"] = []
     dict["text_index"] = []
     graph_text_index = []
     spectra_count = 0
-    for i in known_spectra_lines:
+    for i in dict["known_spectra_lines"]:
         # creating a plot vertically upwards for all the spectra in the spectra list
         blank = 0
         dict["spectra_index"].append(blank)
         dict["text_index"].append(blank)
         graph_text_index.append(blank)
-        text = (str(known_spectra_lines[spectra_count][0][0]))
-        dict["spectra_index"][spectra_count], = dict["ax"].plot([known_spectra_lines[spectra_count][1], known_spectra_lines[spectra_count][1]], infinite,
-                                                color="red", visible=False, label=known_spectra_lines[spectra_count][1],
+        text = (str(dict["known_spectra_lines"][spectra_count][0][0]))
+        dict["spectra_index"][spectra_count], = dict["ax"].plot([dict["known_spectra_lines"][spectra_count][1], dict["known_spectra_lines"][spectra_count][1]], infinite,
+                                                color="red", visible=False, label=dict["known_spectra_lines"][spectra_count][1],
                                                 ls=('dotted'))
         # gives a text labeling each spectra line next to it
-        dict["text_index"][spectra_count] = dict["ax"].text(known_spectra_lines[spectra_count][1], 0.5 * 10 ** 9, str(text), fontsize=12,
+        dict["text_index"][spectra_count] = dict["ax"].text(dict["known_spectra_lines"][spectra_count][1], 0.5 * 10 ** 9, str(text), fontsize=12,
                                             rotation=90, verticalalignment='center', visible=False)
         spectra_count += 1
 
@@ -1078,20 +1078,20 @@ def plot_graph():
 
 
 def submit_shot_selection():
-    print(choice.get())# 1 for York and 2 for SPEX-B
-    print(shot_number.get())# shot number is a string
-    shot_number.set("")
-    choice.set(0)
+    """
+    Sets the shot_number value to the inputed string.
+    :return:
+    """
+    global dict
+    print(dict["choice"].get())# 1 for York and 2 for SPEX-B
+    print(dict["shot_number"].get())# shot number is a string
+    dict["shot_number"].set("")
+    dict["choice"].set(0)
     return
 
 
 @click.command()
 def run_program():
-    click.echo('hello world')
-
-
-if __name__ == "__main__":
-
 
     global dict
     dict = {}
@@ -1111,18 +1111,18 @@ if __name__ == "__main__":
     os.chdir('/common/projects/diagnostics/MAST/SPEXBDMS/Lightfield_output/Data_Files/')
     #loads the data
     # loads the data
-    output = retrieve_data_from_file()
-    o = output
-    dict["o"] = output
-    dict["wavelength_r"] = output['wavelength']
-    dict["t"] = output['time']
-    dict["settings"] = output['settings']
+    dict["output"] = retrieve_data_from_file()
+    o = dict["output"]
+    dict["o"] = dict["output"]
+    dict["wavelength_r"] = dict["output"]['wavelength']
+    dict["t"] = dict["output"]['time']
+    dict["settings"] = dict["output"]['settings']
 
     #if a.size == 0:
-    if len(output['spectra_abs'])>0:
-        dict["data_spectra"] = output['spectra_abs']
+    if len(dict["output"]['spectra_abs'])>0:
+        dict["data_spectra"] = dict["output"]['spectra_abs']
     else:
-        dict["data_spectra"] = output['spectra_counts']
+        dict["data_spectra"] = dict["output"]['spectra_counts']
     #changes the directory back
     os.chdir(cur_dir)
 
@@ -1136,46 +1136,46 @@ if __name__ == "__main__":
     dict["desired_sample_rate"] = dict["current_sample_rate"]
     A_min = 0.1 * 10 ** 19
     B_max = 1 * 10 ** 19
-    horizontal = [["A_min",A_min], ["B_max", B_max]]
-    known_spectra_lines = arr
+    dict["horizontal"] = [["A_min",A_min], ["B_max", B_max]]
+    dict["known_spectra_lines"] = arr
 
-    # makes the main window called root
-    root = Tk.Tk()
-    root.wm_title("GUI for data viewing")
+    # makes the main window called dict["root"]
+    dict["root"] = Tk.Tk()
+    dict["root"].wm_title("GUI for data viewing")
 
     # creating a frame to contain the graph
 
-    subframe = Tk.LabelFrame(root, padx=74, pady=99)
-    subframe.grid(row=0, column=3, padx=0, pady=0, rowspan=10, columnspan = 6)
+    dict["subframe"] = Tk.LabelFrame(dict["root"], padx=74, pady=99)
+    dict["subframe"].grid(row=0, column=3, padx=0, pady=0, rowspan=10, columnspan = 6)
 
     dict["fig"] = plt.Figure()
 
-    btn_1 = Tk.Button(root, text="Change sample rate", command=open_sample_rate_window).grid(row=0, column=0)
+    btn_1 = Tk.Button(dict["root"], text="Change sample rate", command=open_sample_rate_window).grid(row=0, column=0)
 
-    btn_2 = Tk.Button(root, text="Display Spectra", command=open_spectra_window).grid(row=1, column=0)
+    btn_2 = Tk.Button(dict["root"], text="Display Spectra", command=open_spectra_window).grid(row=1, column=0)
 
-    btn_3 = Tk.Button(root, text="Display maximum and minimum", command=open_max_min).grid(row=2, column=0)
+    btn_3 = Tk.Button(dict["root"], text="Display maximum and minimum", command=open_max_min).grid(row=2, column=0)
 
-    btn_4 = Tk.Button(root, text="Load Data", command= load_new_data).grid(row=3, column=0)
+    btn_4 = Tk.Button(dict["root"], text="Load Data", command= load_new_data).grid(row=3, column=0)
 
-    btn_6 = Tk.Button(root, text="Zoom", command= Zooming_picker).grid(row=10, column=3)
+    btn_6 = Tk.Button(dict["root"], text="Zoom", command= Zooming_picker).grid(row=10, column=3)
 
-    btn_7 = Tk.Button(root, text="UnZoom", command= UnZooming).grid(row=10, column=4)
+    btn_7 = Tk.Button(dict["root"], text="UnZoom", command= UnZooming).grid(row=10, column=4)
 
-    btn_8 = Tk.Button(root, text="Intergrate selection", command= intergration_picker).grid(row=10 , column=6)
+    btn_8 = Tk.Button(dict["root"], text="Intergrate selection", command= intergration_picker).grid(row=10 , column=6)
 
-    btn_9 = Tk.Button(root, text="Comparing ratios", command=comparing_ratios_picker).grid(row=10, column=5)
+    btn_9 = Tk.Button(dict["root"], text="Comparing ratios", command=comparing_ratios_picker).grid(row=10, column=5)
 
-    btn_10 = Tk.Button(root, text="Export saved data", command=create_naming_window_external).grid(row=4, column=0)
+    btn_10 = Tk.Button(dict["root"], text="Export saved data", command=create_naming_window_external).grid(row=4, column=0)
 
     # option to load by shot number
-    choice = Tk.IntVar()
-    shot_number = Tk.StringVar()
-    Tk.Label(root, text="Enter shot number:").grid(row=5, column=0)
-    Tk.Entry(root, textvariable=shot_number).grid(row=5, column=0, sticky=Tk.S)
-    Tk.Button(root, text="Load shot", command=submit_shot_selection).grid(row=6, column=0, sticky=Tk.S)
-    Tk.Radiobutton(root, text="York", variable=choice, value=1).grid(row=6, column=0, sticky=Tk.NW)
-    Tk.Radiobutton(root, text="SPEX-B", variable=choice, value=2).grid(row=6, column=0, sticky=Tk.W)
+    dict["choice"] = Tk.IntVar()
+    dict["shot_number"] = Tk.StringVar()
+    Tk.Label(dict["root"], text="Enter shot number:").grid(row=5, column=0)
+    Tk.Entry(dict["root"], textvariable=dict["shot_number"]).grid(row=5, column=0, sticky=Tk.S)
+    Tk.Button(dict["root"], text="Load shot", command=submit_shot_selection).grid(row=6, column=0, sticky=Tk.S)
+    Tk.Radiobutton(dict["root"], text="York", variable=dict["choice"], value=1).grid(row=6, column=0, sticky=Tk.NW)
+    Tk.Radiobutton(dict["root"], text="SPEX-B", variable=dict["choice"], value=2).grid(row=6, column=0, sticky=Tk.W)
 
 
     plot_graph()
@@ -1184,7 +1184,7 @@ if __name__ == "__main__":
     # don't remove unless you like errors in your code
     Tk.mainloop()
 
-
+run_program()
 '''
 “possible improvments: 
 
